@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-__version__ = '20.9.0'
+__version__ = '21.1.1'
 
 PROJECT_NAME = "galaxy-tool-util"
 PROJECT_OWNER = PROJECT_USERAME = "galaxyproject"
@@ -8,6 +6,6 @@ PROJECT_URL = "https://github.com/galaxyproject/galaxy"
 PROJECT_AUTHOR = 'Galaxy Project and Community'
 PROJECT_DESCRIPTION = 'Galaxy Tool and Tool Dependency Utilities'
 PROJECT_EMAIL = 'galaxy-committers@lists.galaxyproject.org'
-RAW_CONTENT_URL = "https://raw.github.com/%s/%s/master/" % (
+RAW_CONTENT_URL = "https://raw.github.com/{}/{}/master/".format(
     PROJECT_USERAME, PROJECT_NAME
 )
