@@ -84,7 +84,7 @@ class Container(metaclass=ABCMeta):
         self.container_info = {}
 
     def prop(self, name, default):
-        destination_name = "{}_{}".format(self.container_type, name)
+        destination_name = f"{self.container_type}_{name}"
         return self.destination_info.get(destination_name, default)
 
     @property
@@ -125,8 +125,10 @@ def preprocess_volumes(volumes_raw_str, container_type):
     ['/a/b:/a:ro', '/a/b/c:/a/b:rw']
     >>> preprocess_volumes("/a/b:default_ro,/a/b/c:rw", DOCKER_CONTAINER_TYPE)
     ['/a/b:ro', '/a/b/c:rw']
+    >>> preprocess_volumes("/a/b:default_ro,/a/b/c:ro", SINGULARITY_CONTAINER_TYPE)
+    ['/a/b:ro', '/a/b/c:ro']
     >>> preprocess_volumes("/a/b:default_ro,/a/b/c:rw", SINGULARITY_CONTAINER_TYPE)
-    ['/a/b:rw', '/a/b/c:rw']
+    ['/a/b', '/a/b/c']
     """
 
     volumes_raw_strs = [v.strip() for v in volumes_raw_str.split(",")]
@@ -160,6 +162,12 @@ def preprocess_volumes(volumes_raw_str, container_type):
 
         volume[1] = how
 
+        # for a while singularity did not allow to specify the bind type rw
+        # (which is the default). so we omit this default
+        # see https://github.com/hpcng/singularity/pull/5487
+        if container_type == SINGULARITY_CONTAINER_TYPE and volume[1] == 'rw':
+            del volume[1]
+
     return [":".join(v) for v in volumes]
 
 
@@ -210,6 +218,12 @@ class HasDockerLikeVolumes:
                     defaults += ",$job_directory/configs:rw"
             if self.job_info.tmp_directory is not None:
                 defaults += ",$tmp_directory:rw"
+                # If a tool definitely has a temp directory available set it to /tmp in container for compat.
+                # with CWL. This is part of that spec and should make it easier to share containers between CWL
+                # and Galaxy.
+                defaults += ",$tmp_directory:/tmp:rw"
+            else:
+                defaults += ",$_GALAXY_JOB_TMP_DIR:rw"
             if self.job_info.home_directory is not None:
                 defaults += ",$home_directory:rw"
             if self.app_info.outputs_to_working_directory:
@@ -268,7 +282,7 @@ class DockerContainer(Container, HasDockerLikeVolumes):
     def containerize_command(self, command):
         env_directives = []
         for pass_through_var in self.tool_info.env_pass_through:
-            env_directives.append('"{}=${}"'.format(pass_through_var, pass_through_var))
+            env_directives.append(f'"{pass_through_var}=${pass_through_var}"')
 
         # Allow destinations to explicitly set environment variables just for
         # docker container. Better approach is to set for destination and then
@@ -276,7 +290,7 @@ class DockerContainer(Container, HasDockerLikeVolumes):
         for key, value in self.destination_info.items():
             if key.startswith("docker_env_"):
                 env = key[len("docker_env_"):]
-                env_directives.append('"{}={}"'.format(env, value))
+                env_directives.append(f'"{env}={value}"')
 
         working_directory = self.job_info.working_directory
         if not working_directory:
@@ -286,11 +300,6 @@ class DockerContainer(Container, HasDockerLikeVolumes):
         preprocessed_volumes_list = preprocess_volumes(volumes_raw, self.container_type)
         # TODO: Remove redundant volumes...
         volumes = [DockerVolume.from_str(v) for v in preprocessed_volumes_list]
-        # If a tool definitely has a temp directory available set it to /tmp in container for compat.
-        # with CWL. This is part of that spec and should make it easier to share containers between CWL
-        # and Galaxy.
-        if self.job_info.tmp_directory is not None:
-            volumes.append(DockerVolume.from_str("%s:/tmp:rw" % self.job_info.tmp_directory))
         volumes_from = self.destination_info.get("docker_volumes_from", docker_util.DEFAULT_VOLUMES_FROM)
 
         docker_host_props = self.docker_host_props
