@@ -3,8 +3,7 @@
 ...using common defaults and configuration mechanisms.
 """
 import os
-
-from six.moves import shlex_quote
+import shlex
 
 from galaxy.util.commands import argv_to_str
 
@@ -69,7 +68,7 @@ def build_docker_cache_command(
 ):
     inspect_image_command = command_shell("inspect", [image], **kwds)
     pull_image_command = command_shell("pull", [image], **kwds)
-    cache_command = "{} > /dev/null 2>&1\n[ $? -ne 0 ] && {} > /dev/null 2>&1\n".format(inspect_image_command, pull_image_command)
+    cache_command = f"{inspect_image_command} > /dev/null 2>&1\n[ $? -ne 0 ] && {pull_image_command} > /dev/null 2>&1\n"
     return cache_command
 
 
@@ -106,10 +105,10 @@ def build_docker_run_command(
     interactive=False,
     terminal=False,
     tag=None,
-    volumes=[],
+    volumes=None,
     volumes_from=DEFAULT_VOLUMES_FROM,
     memory=DEFAULT_MEMORY,
-    env_directives=[],
+    env_directives=None,
     working_directory=DEFAULT_WORKING_DIRECTORY,
     name=None,
     net=DEFAULT_NET,
@@ -123,6 +122,8 @@ def build_docker_run_command(
     guest_ports=False,
     container_name=None
 ):
+    env_directives = env_directives or []
+    volumes = volumes or []
     command_parts = _docker_prefix(
         docker_cmd=docker_cmd,
         sudo=sudo,
@@ -151,15 +152,16 @@ def build_docker_run_command(
     for volume in volumes:
         command_parts.extend(["-v", str(volume)])
     if volumes_from:
-        command_parts.extend(["--volumes-from", shlex_quote(str(volumes_from))])
+        command_parts.extend(["--volumes-from", shlex.quote(str(volumes_from))])
     if memory:
-        command_parts.extend(["-m", shlex_quote(memory)])
+        command_parts.extend(["-m", shlex.quote(memory)])
+    command_parts.extend(["--cpus", '${GALAXY_SLOTS:-1}'])
     if name:
-        command_parts.extend(["--name", shlex_quote(name)])
+        command_parts.extend(["--name", shlex.quote(name)])
     if working_directory:
-        command_parts.extend(["-w", shlex_quote(working_directory)])
+        command_parts.extend(["-w", shlex.quote(working_directory)])
     if net:
-        command_parts.extend(["--net", shlex_quote(net)])
+        command_parts.extend(["--net", shlex.quote(net)])
     if auto_rm:
         command_parts.append("--rm")
     if run_extra_arguments:
@@ -176,22 +178,24 @@ def build_docker_run_command(
         command_parts.extend(["--user", user])
     full_image = image
     if tag:
-        full_image = "{}:{}".format(full_image, tag)
-    command_parts.append(shlex_quote(full_image))
+        full_image = f"{full_image}:{tag}"
+    command_parts.append(shlex.quote(full_image))
     command_parts.append(container_command)
     return " ".join(command_parts)
 
 
-def command_list(command, command_args=[], **kwds):
+def command_list(command, command_args=None, **kwds):
     """Return Docker command as an argv list."""
+    command_args = command_args or []
     command_parts = _docker_prefix(**kwds)
     command_parts.append(command)
     command_parts.extend(command_args)
     return command_parts
 
 
-def command_shell(command, command_args=[], **kwds):
+def command_shell(command, command_args=None, **kwds):
     """Return Docker command as a string for a shell or command-list."""
+    command_args = command_args or []
     cmd = command_list(command, command_args, **kwds)
     to_str = kwds.get("to_str", True)
     if to_str:
@@ -223,6 +227,7 @@ def parse_port_text(port_text):
     >>> slurm_ports = parse_port_text("8888/tcp -> 0.0.0.0:32769")
     >>> slurm_ports[8888]['host']
     '0.0.0.0'
+    >>> ports = parse_port_text("5432/tcp -> :::5432")
     """
     ports = None
     if port_text is not None:
@@ -231,7 +236,11 @@ def parse_port_text(port_text):
             if " -> " not in line:
                 raise Exception("Cannot parse host and port from line [%s]" % line)
             tool, host = line.split(" -> ", 1)
-            hostname, port = host.split(':')
+            hostname, port = host.rsplit(':', 1)
+            if hostname == '::':
+                # Skip unspecified IPv6 address, which is also specified as 0:0:0:0 in another line.
+                # This is brittle of course, but so is parsing the container ports like this.
+                continue
             port = int(port)
             tool_p, tool_prot = tool.split("/")
             tool_p = int(tool_p)
