@@ -12,6 +12,7 @@ Build a mulled image with:
 import json
 import logging
 import os
+import shlex
 import shutil
 import stat
 import string
@@ -19,11 +20,7 @@ import subprocess
 import sys
 from sys import platform as _platform
 
-from six.moves import shlex_quote
-try:
-    import yaml
-except ImportError:
-    yaml = None
+import yaml
 
 from galaxy.tool_util.deps import installable
 from galaxy.tool_util.deps.conda_util import best_search_result
@@ -49,9 +46,12 @@ from ..conda_compat import MetaData
 log = logging.getLogger(__name__)
 
 DIRNAME = os.path.dirname(__file__)
-DEFAULT_BASE_IMAGE = "bgruening/busybox-bash:0.1"
-DEFAULT_EXTENDED_BASE_IMAGE = "bioconda/extended-base-image:latest"
-DEFAULT_CHANNELS = ["conda-forge", "bioconda"]
+DEFAULT_BASE_IMAGE = os.environ.get("DEFAULT_BASE_IMAGE", "quay.io/bioconda/base-glibc-busybox-bash:latest")
+DEFAULT_EXTENDED_BASE_IMAGE = os.environ.get("DEFAULT_EXTENDED_BASE_IMAGE", "quay.io/bioconda/base-glibc-debian-bash:latest")
+if 'DEFAULT_MULLED_CONDA_CHANNELS' in os.environ:
+    DEFAULT_CHANNELS = os.environ['DEFAULT_MULLED_CONDA_CHANNELS'].split(',')
+else:
+    DEFAULT_CHANNELS = ["conda-forge", "bioconda"]
 DEFAULT_REPOSITORY_TEMPLATE = "quay.io/${namespace}/${image}"
 DEFAULT_BINDS = ["build/dist:/usr/local/"]
 DEFAULT_WORKING_DIR = '/source/'
@@ -220,8 +220,8 @@ def mull_targets(
 
     for channel in channels:
         if channel.startswith('file://'):
-            bind_path = channel.lstrip('file://')
-            binds.append('/{}:/{}'.format(bind_path, bind_path))
+            bind_path = channel[7:]
+            binds.append(f'/{bind_path}:/{bind_path}')
 
     channels = ",".join(channels)
     target_str = ",".join(map(conda_build_target_str, targets))
@@ -252,19 +252,19 @@ def mull_targets(
         involucro_args.extend(["-set", "SINGULARITY=1"])
         involucro_args.extend(["-set", "SINGULARITY_IMAGE_NAME=%s" % singularity_image_name])
         involucro_args.extend(["-set", "SINGULARITY_IMAGE_DIR=%s" % singularity_image_dir])
-        involucro_args.extend(["-set", "USER_ID={}:{}".format(os.getuid(), os.getgid())])
+        involucro_args.extend(["-set", f"USER_ID={os.getuid()}:{os.getgid()}"])
     if test:
         involucro_args.extend(["-set", "TEST=%s" % test])
     if conda_version is not None:
         verbose = "--verbose" if verbose else "--quiet"
-        involucro_args.extend(["-set", "PREINSTALL=conda install {} --yes conda={}".format(verbose, conda_version)])
+        involucro_args.extend(["-set", f"PREINSTALL=conda install {verbose} --yes conda={conda_version}"])
     involucro_args.append(command)
     if test_files:
         test_bind = []
         for test_file in test_files:
             if ':' not in test_file:
                 if os.path.exists(test_file):
-                    test_bind.append("{}:{}/{}".format(test_file, DEFAULT_WORKING_DIR, test_file))
+                    test_bind.append(f"{test_file}:{DEFAULT_WORKING_DIR}/{test_file}")
             else:
                 if os.path.exists(test_file.split(':')[0]):
                     test_bind.append(test_file)
@@ -272,7 +272,7 @@ def mull_targets(
             involucro_args.insert(6, '-set')
             involucro_args.insert(7, "TEST_BINDS=%s" % ",".join(test_bind))
     cmd = involucro_context.build_command(involucro_args)
-    print('Executing: ' + ' '.join(shlex_quote(_) for _ in cmd))
+    print('Executing: ' + ' '.join(shlex.quote(_) for _ in cmd))
     if dry_run:
         return 0
     ensure_installed(involucro_context, True)
